@@ -38,7 +38,7 @@
  *
  * Since: 0.10.0
  */
-#define GARROW_VERSION_MAJOR (17)
+#define GARROW_VERSION_MAJOR (21)
 
 /**
  * GARROW_VERSION_MINOR:
@@ -110,6 +110,42 @@
 #  define GARROW_UNAVAILABLE(major, minor) G_UNAVAILABLE(major, minor)
 #endif
 
+/**
+ * GARROW_VERSION_21_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 21.0.0
+ */
+#define GARROW_VERSION_21_0 G_ENCODE_VERSION(21, 0)
+
+/**
+ * GARROW_VERSION_20_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 20.0.0
+ */
+#define GARROW_VERSION_20_0 G_ENCODE_VERSION(20, 0)
+
+/**
+ * GARROW_VERSION_19_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 19.0.0
+ */
+#define GARROW_VERSION_19_0 G_ENCODE_VERSION(19, 0)
+
+/**
+ * GARROW_VERSION_18_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 18.0.0
+ */
+#define GARROW_VERSION_18_0 G_ENCODE_VERSION(18, 0)
+
 /**
  * GARROW_VERSION_17_0:
  *
@@ -397,6 +433,62 @@
 
 #define GARROW_AVAILABLE_IN_ALL GARROW_EXTERN
 
+#if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_21_0
+#  define GARROW_DEPRECATED_IN_21_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_21_0_FOR(function) GARROW_DEPRECATED_FOR(function)
+#else
+#  define GARROW_DEPRECATED_IN_21_0
+#  define GARROW_DEPRECATED_IN_21_0_FOR(function)
+#endif
+
+#if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_21_0
+#  define GARROW_AVAILABLE_IN_21_0 GARROW_EXTERN GARROW_UNAVAILABLE(21, 0)
+#else
+#  define GARROW_AVAILABLE_IN_21_0 GARROW_EXTERN
+#endif
+
+#if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_20_0
+#  define GARROW_DEPRECATED_IN_20_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_20_0_FOR(function) GARROW_DEPRECATED_FOR(function)
+#else
+#  define GARROW_DEPRECATED_IN_20_0
+#  define GARROW_DEPRECATED_IN_20_0_FOR(function)
+#endif
+
+#if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_20_0
+#  define GARROW_AVAILABLE_IN_20_0 GARROW_EXTERN GARROW_UNAVAILABLE(20, 0)
+#else
+#  define GARROW_AVAILABLE_IN_20_0 GARROW_EXTERN
+#endif
+
+#if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_19_0
+#  define GARROW_DEPRECATED_IN_19_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_19_0_FOR(function) GARROW_DEPRECATED_FOR(function)
+#else
+#  define GARROW_DEPRECATED_IN_19_0
+#  define GARROW_DEPRECATED_IN_19_0_FOR(function)
+#endif
+
+#if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_19_0
+#  define GARROW_AVAILABLE_IN_19_0 GARROW_EXTERN GARROW_UNAVAILABLE(19, 0)
+#else
+#  define GARROW_AVAILABLE_IN_19_0 GARROW_EXTERN
+#endif
+
+#if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_18_0
+#  define GARROW_DEPRECATED_IN_18_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_18_0_FOR(function) GARROW_DEPRECATED_FOR(function)
+#else
+#  define GARROW_DEPRECATED_IN_18_0
+#  define GARROW_DEPRECATED_IN_18_0_FOR(function)
+#endif
+
+#if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_18_0
+#  define GARROW_AVAILABLE_IN_18_0 GARROW_EXTERN GARROW_UNAVAILABLE(18, 0)
+#else
+#  define GARROW_AVAILABLE_IN_18_0 GARROW_EXTERN
+#endif
+
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_17_0
 #  define GARROW_DEPRECATED_IN_17_0               GARROW_DEPRECATED
 #  define GARROW_DEPRECATED_IN_17_0_FOR(function) GARROW_DEPRECATED_FOR(function)
